==> assemble-release-plan-5.1.0-temp.0.tgz: package/src/utils.ts <==
import { PackageGroup, VersionType } from "@changesets/types";
import { Package } from "@manypkg/get-packages";
import semver from "semver";
import { InternalRelease } from "./types";

export function getHighestReleaseType(
  releases: InternalRelease[]
): VersionType {
  if (releases.length === 0) {
    throw new Error(
      `Large internal changesets error in calculating when calculating highest release type in the set of releases. Please contact the maintainers`
    );
  }

  let highestReleaseType = releases[0].type;

  for (let release of releases) {
    switch (release.type) {
      case "major":
        return "major";
      case "minor":
        highestReleaseType = "minor";
        break;
      // patch never needs to override another value
    }
  }

  return highestReleaseType;
}

export function getCurrentHighestVersion(
  packageGroup: PackageGroup,
  packagesByName: Map<string, Package>
): string {
  let highestVersion: string | undefined;

  for (let pkgName of packageGroup) {
    let pkg = packagesByName.get(pkgName);

    if (!pkg) {
      console.error(
        `FATAL ERROR IN CHANGESETS! We were unable to version for package group: ${pkgName} in package group: ${packageGroup.toString()}`
      );
      throw new Error(`fatal: could not resolve linked packages`);
    }

    if (
      highestVersion === undefined ||
      semver.gt(pkg.packageJson.version, highestVersion)
    ) {
      highestVersion = pkg.packageJson.version;
    }
  }

  return highestVersion!;
}

==> assemble-release-plan-5.1.1-temp.0.tgz: package/src/utils.ts <==
import { PackageGroup, VersionType, PackageJSON } from "@changesets/types";
import { Package } from "@manypkg/get-packages";
import semver from "semver";
import { InternalRelease } from "./types";

export function getHighestReleaseType(
  releases: InternalRelease[]
): VersionType {
  if (releases.length === 0) {
    throw new Error(
      `Large internal Changesets error when calculating highest release type in the set of releases. Please contact the maintainers`
    );
  }

  let highestReleaseType: VersionType = "none";

  for (let release of releases) {
    switch (release.type) {
      case "major":
        return "major";
      case "minor":
        highestReleaseType = "minor";
        break;
      case "patch":
        if (highestReleaseType === "none") {
          highestReleaseType = "patch";
        }
        break;
    }
  }

  return highestReleaseType;
}

export function getCurrentHighestVersion(
  packageGroup: PackageGroup,
  packagesByName: Map<string, Package>
): string {
  let highestVersion: string | undefined;

  for (let pkgName of packageGroup) {
    let pkg = packagesByName.get(pkgName);

    if (!pkg) {
      console.error(
        `FATAL ERROR IN CHANGESETS! We were unable to version for package group: ${pkgName} in package group: ${packageGroup.toString()}`
      );
      throw new Error(`fatal: could not resolve linked packages`);
    }

    if (
      highestVersion === undefined ||
      semver.gt(pkg.packageJson.version, highestVersion)
    ) {
      highestVersion = pkg.packageJson.version;
    }
  }

  return highestVersion!;
}

export const getPkgJsonVersion = (packageJson: PackageJSON): string => {
  if (packageJson.version === undefined) {
    return "0.0.0";
  }
  if (typeof packageJson.version === "string") {
    return packageJson.version;
  }
  throw new Error(
    `Package "${packageJson.name}" has invalid version property: ${packageJson.version}.`
  );
};
